@@ -13,7 +13,7 @@ from typing import Optional
 import click
 
 from worktree_manager.config import load_config
-from worktree_manager.utils import ProjectType, find_worktree_root
+from worktree_manager.utils import find_worktree_root
 
 
 @click.group()
@@ -41,14 +41,6 @@ def clone(repo: str):
     with open(path.join(project_dir, repo_name, ".worktree"), "w") as f:
         f.write("")
 
-@cli.command(name="on", help="work on a project")
-@click.argument("project", type=ProjectType())
-def work_on(project: str):
-    config = load_config()
-    projects_dir = expanduser(config["projects.path"])
-    run(f"cd {path.join(projects_dir, project)}".split(" "))
-
-
 # @click.option(
 #     "-p",
 #     "--project",
